@@ -42,7 +42,7 @@ static void gtk_plot_candle_draw_symbol	(GtkPlotData *data,
 					 gdouble dz, 
 					 gdouble da);
 
-extern inline gint roundint (gdouble x);
+gint roundint (gdouble x);
 
 
 static GtkPlotDataClass *parent_class = NULL;
