@@ -1,6 +1,6 @@
 char *fake = N_("Compose two functions");
 char *fake = N_("Compose a function with itself n times, passing x as argument, and returning x if n == 0");
-char *fake = N_("Print a table of values for f(n) for numbers from from vector v, or if v is a number for integers from 1 to v");
+char *fake = N_("Print a table of values for f(n) for numbers from vector v, or if v is a number for integers from 1 to v");
 char *fake = N_("Make a string");
 char *fake = N_("Tolerance of the Chop function");
 char *fake = N_("How many iterations to try to find the limit for continuity and limits");
@@ -106,7 +106,7 @@ char *fake = N_("Conjugate transpose of a matrix (adjoint)");
 char *fake = N_("Calculate convolution of two horizontal vectors");
 char *fake = N_("Calculate convolution of two horizontal vectors");
 char *fake = N_("CrossProduct of two vectors in R^3");
-char *fake = N_("Get the determinantal divisors of an integer matrix (not its characteristic)");
+char *fake = N_("Get the determinantal divisors of an integer matrix");
 char *fake = N_("Direct sum of matrices");
 char *fake = N_("Direct sum of a vector of matrices");
 char *fake = N_("Get the eigenvalues of a matrix (Currently only for up to 4x4 or triangular matrices)");
@@ -116,7 +116,7 @@ char *fake = N_("Hankel matrix");
 char *fake = N_("Hilbert matrix of order n");
 char *fake = N_("Get the image (columnspace) of a linear transform");
 char *fake = N_("Get the Inf Norm of a vector");
-char *fake = N_("Get the invariant factors of a square integer matrix (not its characteristic)");
+char *fake = N_("Get the invariant factors of a square integer matrix");
 char *fake = N_("Inverse Hilbert matrix of order n");
 char *fake = N_("Is a matrix Hermitian");
 char *fake = N_("Test if a vector is in a subspace");
@@ -150,7 +150,7 @@ char *fake = N_("Get a basis matrix for the rowspace of a matrix");
 char *fake = N_("Evaluate (v,w) with respect to the sesquilinear form given by the matrix A");
 char *fake = N_("Return a function that evaluates two vectors with respect to the sesquilinear form given by A");
 char *fake = N_("Smith Normal Form for fields (will end up with 1's on the diagonal)");
-char *fake = N_("Smith Normal Form for square integer matrices (not its characteristic)");
+char *fake = N_("Smith Normal Form for square integer matrices");
 char *fake = N_("Return the Toeplitz matrix constructed given the first column c and (optionally) the first row r.");
 char *fake = N_("Calculate the trace of a matrix");
 char *fake = N_("Transpose of a matrix");
@@ -167,7 +167,7 @@ char *fake = N_("Factorial: n(n-1)(n-2)...");
 char *fake = N_("Falling factorial: (n)_k = n(n-1)...(n-(k-1))");
 char *fake = N_("Calculate nth Fibonacci number");
 char *fake = N_("Calculate the Frobenius number for a coin problem");
-char *fake = N_("Galois matrix given a linear combining rule (a_1*x_+...+a_n*x_n=x_(n+1))");
+char *fake = N_("Galois matrix given a linear combining rule (a_1*x_1+...+a_n*x_n=x_(n+1))");
 char *fake = N_("Use greedy algorithm to find c, for c . v = n.  (v must be sorted)");
 char *fake = N_("Harmonic Number, the nth harmonic number of order r");
 char *fake = N_("Hofstadter's function q(n) defined by q(1)=1, q(2)=1, q(n)=q(n-q(n-1))+q(n-q(n-2))");
@@ -177,7 +177,7 @@ char *fake = N_("Get the Pascal's triangle as a matrix");
 char *fake = N_("(Pochhammer) Rising factorial: (n)_k = n(n+1)...(n+(k-1))");
 char *fake = N_("Stirling number of the first kind");
 char *fake = N_("Stirling number of the second kind");
-char *fake = N_("Subfactorial: n! times sum_{k=1}^n (-1)^k/k!");
+char *fake = N_("Subfactorial: n! times sum_{k=0}^n (-1)^k/k!");
 char *fake = N_("Calculate the nth triangular number");
 char *fake = N_("Calculate permutations");
 char *fake = N_("Integration of f by Composite Simpson's Rule on the interval [a,b] with the number of steps calculated by the fourth derivative bound and the desired tolerance");
@@ -237,8 +237,8 @@ char *fake = N_("Find root of a function using the bisection method to within TO
 char *fake = N_("Find root of a function using the method of false position to within TOL tolerance in up to N iterations.  f(a) and f(b) must have opposite signs.");
 char *fake = N_("Find root of a function using the Muller's method");
 char *fake = N_("Find root of a function using the secant method to within TOL tolerance in up to N iterations.  f(a) and f(b) must have opposite signs.");
-char *fake = N_("Attempt to find a zero of a functionf with derivative df and second derivative ddf using Halleys's method, returning after two successive values are within epsilon or after maxn tries (then returns null)");
-char *fake = N_("Attempt to find a zero of a functionf with derivative df using Newton's method, returning after two successive values are within epsilon or after maxn tries (then returns null)");
+char *fake = N_("Attempt to find a zero of a function f with derivative df and second derivative ddf using Halley's method, returning after two successive values are within epsilon or after maxn tries (then returns null)");
+char *fake = N_("Attempt to find a zero of a function f with derivative df using Newton's method, returning after two successive values are within epsilon or after maxn tries (then returns null)");
 char *fake = N_("Find roots of a polynomial (given as vector of coefficients)");
 char *fake = N_("Find roots of a quartic polynomial (given as vector of coefficients)");
 char *fake = N_("Use classical non-adaptive Runge-Kutta of fourth order method to numerically solve y'=f(x,y) for initial x0,y0 going to x1 with n increments, returns y at x1");
